"use strict";

var _massageDataOut = _interopRequireDefault(require("./massageDataOut"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

var props;
beforeEach(function () {
  props = {
    alwaysReturnArray: false,
    multiple: false,
    parseTo: "string"
  };
});
it("should return empty array if alwaysReturnArray", function () {
  props.alwaysReturnArray = true;
  expect((0, _massageDataOut.default)(props, [])).toStrictEqual([]);
});
it("should return empty array if multiple", function () {
  props.multiple = true;
  expect((0, _massageDataOut.default)(props, [])).toStrictEqual([]);
});
describe("string", function () {
  it("should return empty", function () {
    expect((0, _massageDataOut.default)(props, [])).toStrictEqual("");
  });
  it("single", function () {
    expect((0, _massageDataOut.default)(props, ["value"])).toStrictEqual("value");
  });
  it("alwaysReturnArray", function () {
    props.alwaysReturnArray = true;
    expect((0, _massageDataOut.default)(props, ["value"])).toStrictEqual(["value"]);
  });
  it("single and multiple = true", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, ["value"])).toStrictEqual(["value"]);
  });
  it("multiple", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, ["value", "other"])).toStrictEqual(["value", "other"]);
  });
});
describe("number", function () {
  beforeEach(function () {
    props.parseTo = "number";
  });
  it("should return empty", function () {
    expect((0, _massageDataOut.default)(props, [])).toStrictEqual(undefined);
  });
  it("single", function () {
    expect((0, _massageDataOut.default)(props, [1])).toStrictEqual(1);
  });
  it("multiple", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, [1, 2])).toStrictEqual([1, 2]);
  });
});
describe("int", function () {
  beforeEach(function () {
    props.parseTo = "int";
  });
  it("should return empty", function () {
    expect((0, _massageDataOut.default)(props, [])).toStrictEqual(undefined);
  });
  it("single", function () {
    expect((0, _massageDataOut.default)(props, [1])).toStrictEqual(1);
  });
  it("multiple", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, [1, 2])).toStrictEqual([1, 2]);
  });
});
describe("float", function () {
  beforeEach(function () {
    props.parseTo = "float";
  });
  it("should return empty", function () {
    expect((0, _massageDataOut.default)(props, [])).toStrictEqual(undefined);
  });
  it("single", function () {
    expect((0, _massageDataOut.default)(props, [0.1])).toStrictEqual(0.1);
  });
  it("multiple", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, [0.1, 0.2])).toStrictEqual([0.1, 0.2]);
  });
});
describe("boolean", function () {
  beforeEach(function () {
    props.parseTo = "boolean";
  });
  it("should return empty", function () {
    expect((0, _massageDataOut.default)(props, [])).toStrictEqual(undefined);
  });
  it("single", function () {
    expect((0, _massageDataOut.default)(props, ["true"])).toStrictEqual(true);
  });
  it("multiple", function () {
    props.multiple = true;
    expect((0, _massageDataOut.default)(props, ["true", "false", "not", "any", "thing", "TRuE"])).toStrictEqual([true, false, true]);
  });
});